@@ -66,15 +66,13 @@ double diggracif(prop, state, cdata)
      Cdata *cdata;
 {
   int npts, ix, ixp1, j;
-  double *period, *x, *y;
+  double *x, *y;
   double u, v;
   double d2, pairprod, cifval;
   Diggra *diggra;
 
   diggra = (Diggra *) cdata;
 
-  period = diggra->period;
-
   u  = prop.u;
   v  = prop.v;
   ix = prop.ix;
